==> DEDS_1.16.0.zip: DEDS/doc/DEDS.R <==
###################################################
### chunk number 1: loadaffy
###################################################
library(DEDS)
data(affySpikeIn) 


###################################################
### chunk number 2: showaffy
###################################################
dim(affySpikeIn) 
affySpikeIn.L
spikedgene


###################################################
### chunk number 3: dedsaffy
###################################################
deds.affy <- deds.stat.linkC(affySpikeIn, affySpikeIn.L, B=400, nsig=100) 


###################################################
### chunk number 4: showdedsaffy
###################################################
topgenes(deds.affy, number=20, genelist=affySpikeIn.gnames)


###################################################
### chunk number 5: pairsaffy eval=FALSE
###################################################
## pairs(deds.affy, subset=c(2:12626), thresh=0.01, legend=F)


###################################################
### chunk number 6: qqaffy eval=FALSE
###################################################
## qqnorm(deds.affy, subset=c(2:12626), thresh=0.01)


###################################################
### chunk number 7: loadApoA1
###################################################
data(ApoA1) 


###################################################
### chunk number 8: showApoA1
###################################################
dim(ApoA1) 
ApoA1.L


###################################################
### chunk number 9: dedsApoA1
###################################################
deds.ApoA1 <- deds.stat.linkC(ApoA1, ApoA1.L, B=400, adj="adjp" ) 


###################################################
### chunk number 10: 
###################################################
sum(deds.ApoA1$p<=0.01)
sum(deds.ApoA1$p<=0.05)


###################################################
### chunk number 11: showdedsApoA1
###################################################
topgenes(deds.ApoA1, number=9)


###################################################
### chunk number 12: pairsApoA1
###################################################
pairs(deds.ApoA1, legend=F)


###################################################
### chunk number 13: tstat eval=FALSE
###################################################
## t <- comp.t(L=affySpikeIn.L)
## t.affy <- t(affySpikeIn)


###################################################
### chunk number 14: tstat2 eval=FALSE
###################################################
## t.affy <- comp.stat(affySpikeIn, affySpikeIn.L, test='t')

==> DEDS_1.24.0.zip: DEDS/doc/DEDS.R <==
###################################################
### chunk number 1: loadaffy
###################################################
#line 99 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
library(DEDS)
data(affySpikeIn) 


###################################################
### chunk number 2: showaffy
###################################################
#line 133 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
dim(affySpikeIn) 
affySpikeIn.L
spikedgene


###################################################
### chunk number 3: dedsaffy
###################################################
#line 185 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
deds.affy <- deds.stat.linkC(affySpikeIn, affySpikeIn.L, B=400, nsig=100) 


###################################################
### chunk number 4: showdedsaffy
###################################################
#line 189 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
topgenes(deds.affy, number=20, genelist=affySpikeIn.gnames)


###################################################
### chunk number 5: pairsaffy eval=FALSE
###################################################
## #line 206 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
## pairs(deds.affy, subset=c(2:12626), thresh=0.01, legend=F)


###################################################
### chunk number 6: qqaffy eval=FALSE
###################################################
## #line 211 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
## qqnorm(deds.affy, subset=c(2:12626), thresh=0.01)


###################################################
### chunk number 7: loadApoA1
###################################################
#line 228 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
data(ApoA1) 


###################################################
### chunk number 8: showApoA1
###################################################
#line 248 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
dim(ApoA1) 
ApoA1.L


###################################################
### chunk number 9: dedsApoA1
###################################################
#line 260 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
deds.ApoA1 <- deds.stat.linkC(ApoA1, ApoA1.L, B=400, adj="adjp" ) 


###################################################
### chunk number 10: 
###################################################
#line 264 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
sum(deds.ApoA1$p<=0.01)
sum(deds.ApoA1$p<=0.05)


###################################################
### chunk number 11: showdedsApoA1
###################################################
#line 269 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
topgenes(deds.ApoA1, number=9)


###################################################
### chunk number 12: pairsApoA1
###################################################
#line 273 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
pairs(deds.ApoA1, legend=F)


###################################################
### chunk number 13: tstat eval=FALSE
###################################################
## #line 319 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
## t <- comp.t(L=affySpikeIn.L)
## t.affy <- t(affySpikeIn)


###################################################
### chunk number 14: tstat2 eval=FALSE
###################################################
## #line 355 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpmj0Rtc/R.INSTALL6e9f668a/DEDS/inst/doc/DEDS.rnw"
## t.affy <- comp.stat(affySpikeIn, affySpikeIn.L, test='t')
